<template>
  <swiper
    :style="{
      '--swiper-navigation-color': '#ff9800',
      '--swiper-pagination-color': '#ff9800',
    }"
    :rewind="true"
    :pagination="{ clickable: true }"
    :loop="true"
    :autoplay="{ delay: 10000 }"
    :navigation="true"
    :slides-per-view="1"
    :space-between="10"
    :breakpoints="{
      1024: { slidesPerView: 3 },
      768: { slidesPerView: 2 },
      576: { slidesPerView: 1 }
    }"
    :modules="[Navigation, Pagination,Autoplay]"
    class="mySwiper w-100"
    v-if="banners.length > 0"
  >
    <swiper-slide v-for="banner in banners" :key="banner.id">
      <a :href="banner.link" target="_blank" rel="noopener noreferrer">
        <img :src="banner.image" :alt="banner.title" class="rounded object-fit-fill" />
      </a>
    </swiper-slide>
  </swiper>
</template>

<script setup>
import { ref, onMounted } from 'vue'
import { useCookie } from '#app'
import { useRoute, useRouter } from 'vue-router'
import { Swiper, SwiperSlide } from 'swiper/vue'
import 'swiper/css'
import 'swiper/css/navigation'
import 'swiper/css/pagination'
import 'swiper/css/autoplay'; // ← اضافه کن

import { Navigation, Pagination, Autoplay } from 'swiper/modules'; // ← اضافه کن Autoplay

const banners = ref([])
const {$api} = useNuxtApp();

const getBanners = async () => {
  await $api
    .post('/banner')
    .then((value) => {
      banners.value = value.data.data || []
    })
}

onMounted(() => {
  getBanners()
})
</script>

<style scoped>
.mySwiper {
  width: 100%;
  display: flex;
  height: 170px;
  align-items: center;
}
.mySwiper img {
  width: 100%;
  height: 120px;
  object-fit: cover;
  border-radius: 8px;
}
</style>
